@@ -2,7 +2,7 @@ import slai
 import torch
 
 
-class ModelHandler(slai.base_handler):
+class ModelHandler(slai.BaseModelHandler):
     def model_inputs(self):
         return {"input_1": slai.inputs.Float, "input_2": slai.inputs.Float}
 
